==> haskell-free-4.12.4-24-i686.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 4.12.4
id: free-4.12.4-DZCTkfqdDiF4eKUVutuQ1W
key: free-4.12.4-DZCTkfqdDiF4eKUVutuQ1W
license: BSD3
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Applicative.Free Control.Applicative.Free.Final
    Control.Applicative.Trans.Free Control.Alternative.Free
    Control.Alternative.Free.Final Control.Comonad.Cofree
    Control.Comonad.Cofree.Class Control.Comonad.Trans.Cofree
    Control.Comonad.Trans.Coiter Control.Monad.Free
    Control.Monad.Free.Church Control.Monad.Free.Class
    Control.Monad.Free.TH Control.Monad.Trans.Free
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
abi: 150d38d1c25ffe132b08e88bc20d8594
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/free-4.12.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/free-4.12.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/free-4.12.4
hs-libraries: HSfree-4.12.4-DZCTkfqdDiF4eKUVutuQ1W
depends:
    base-4.9.0.0 bifunctors-5.4.1-GkfNQTKDQae69fnI43VaS4
    comonad-5-FocVP0xchqoELxW0q31ZBF containers-0.5.7.1
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    prelude-extras-0.4.0.3-FAyB4iuuM7cHXdrLMZtdXq
    profunctors-5.2-DDzWnW7PWEeEYRCGSjacrC
    semigroupoids-5.1-KBxlUMJdBcK6rKu26wa0Rl
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz template-haskell-2.11.0.0
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-4.12.4-26-i686.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 4.12.4
id: free-4.12.4-3djEuuVf78E7uL6ewIYMHB
key: free-4.12.4-3djEuuVf78E7uL6ewIYMHB
license: BSD3
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Applicative.Free Control.Applicative.Free.Final
    Control.Applicative.Trans.Free Control.Alternative.Free
    Control.Alternative.Free.Final Control.Comonad.Cofree
    Control.Comonad.Cofree.Class Control.Comonad.Trans.Cofree
    Control.Comonad.Trans.Coiter Control.Monad.Free
    Control.Monad.Free.Church Control.Monad.Free.Class
    Control.Monad.Free.TH Control.Monad.Trans.Free
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
abi: e17419e78695d5108aee42c312a35e50
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/free-4.12.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/free-4.12.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/free-4.12.4
hs-libraries: HSfree-4.12.4-3djEuuVf78E7uL6ewIYMHB
depends:
    base-4.9.0.0 bifunctors-5.4.1-Ac6G6TmMVPE36jXOz0jDKq
    comonad-5-IFpew4VeZSgJKPLIcHpKjC containers-0.5.7.1
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    prelude-extras-0.4.0.3-FAyB4iuuM7cHXdrLMZtdXq
    profunctors-5.2-1HLm9WoKgF5GvKRjOhOJmS
    semigroupoids-5.1-mvlh42rhjC5vNXakyMT7n
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz template-haskell-2.11.0.0
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
